@@ -1,5 +1,9 @@
 #!/usr/bin/python
+'''
+Geoffrey Weal, make_finish_files.py, 10/02/2021
 
+This program is designed to place finish files in all subdirectories that also include a Run.py file
+'''
 import os, sys
 
 def make_finish_file(path):
