@@ -1,5 +1,9 @@
 #!/usr/bin/python
+'''
+Geoffrey Weal, remove_lock_files.py, 10/02/2021
 
+This program is designed to remove all the ga_running.lock files from subdirectories that this program is run from.
+'''
 import os, sys
 
 lock_name = 'ga_running.lock'
